@@ -6,14 +6,13 @@ import urllib.parse
 from functools import partial
 
 from PyQt5.QtCore import QDir, QSettings, QUrl, pyqtRemoveInputHook, pyqtSignal
-from PyQt5.QtGui import QDesktopServices, QIcon
+from PyQt5.QtGui import QDesktopServices
 from PyQt5.QtWidgets import QAction, QApplication, QFileDialog, QFrame, QLabel, QMainWindow, QMenu, QMessageBox, QSplitter, QVBoxLayout, QWidget
 
 from . import loadshortcuts as ls
 from . import m3u, genres
 from . import mainwin
 from . import tagmodel
-from . import webdb
 from . import version_string, changeset
 from .mainwin import funcs as mainfuncs
 from .masstag import dialogs
@@ -70,7 +69,7 @@ def create_tool_windows(parent, extra=None):
     cparser.filename = ls.menu_path
     widgets = (mainwin.tagpanel, mainwin.artwork,
                mainwin.dirview, mainwin.patterncombo, mainwin.filterwin,
-               webdb, mainwin.storedtags, mainwin.logdialog,
+               mainwin.tagsources, mainwin.storedtags, mainwin.logdialog,
                dialogs)
 
     controls = [z.control for z in widgets]
@@ -314,7 +313,7 @@ def help_menu(parent):
     issue_link = QAction(translate("Menus", '&Report a problem'), parent)
     connect(issue_link, create_bug_report_issue)
 
-    about_icon = get_icon('help-about', QIcon())
+    about_icon = get_icon('help-about')
     about = QAction(about_icon,
                     translate("Menus", 'About puddletag'), parent)
     connect(about, partial(mainfuncs.show_about, parent))
@@ -353,6 +352,7 @@ class PreviewLabel(QLabel):
         self._enabled = not self._enabled
         self.valueChanged.emit(self._enabled)
 
+
 def _openFilesFilterFilename(filename):
     filename = os.path.abspath(filename)
     if isinstance(filename, str):
@@ -360,6 +360,11 @@ def _openFilesFilterFilename(filename):
     return filename
 
 
+# set in MainWin.__init__
+add_shortcuts = None
+remove_shortcuts = None
+
+
 class MainWin(QMainWindow):
     loadFiles = pyqtSignal(object, object, object, object, object, name='loadFiles')
     always = pyqtSignal(bool, name='always')
@@ -543,9 +548,9 @@ class MainWin(QMainWindow):
             initial = initial.decode('utf8', 'replace')
 
         if len(dirs) > 1:
-            self.setWindowTitle(translate("Main Window", 'puddletag: %1 + others').arg(initial))
+            self.setWindowTitle(translate('Main Window', "puddletag: {} + others").format(initial))
         else:
-            self.setWindowTitle(translate("Main Window", 'puddletag: %1').arg(initial))
+            self.setWindowTitle(translate('Main Window', "puddletag: {}").format(initial))
 
         self._lastdir = dirs
 
@@ -632,7 +637,7 @@ class MainWin(QMainWindow):
     def loadPlayList(self):
         dirname = self._lastdir[0] if self._lastdir else QDir.homePath()
         selectedFile = QFileDialog.getOpenFileName(self,
-                                                   translate("Playlist", translate("Playlist", 'Select m3u file...')), )
+                                                   translate("Playlist", translate("Playlist", 'Select m3u file...')),)
         filename = selectedFile[0]
         if not filename:
             return
@@ -642,14 +647,20 @@ class MainWin(QMainWindow):
         except (OSError, IOError) as e:
             QMessageBox.information(self._table,
                                     translate("Defaults", 'Error'),
-                                    translate("Playlist", 'An error occured while reading <b>%1</b> (%2)').arg(filename).arg(e.strerror))
+                                    translate('Playlist',
+                                              "An error occured while reading <b>{}</b> ({})"
+                                              ).format(filename, e.strerror)
+                                    )
         except (UnicodeError) as e:
             QMessageBox.information(self._table,
                                     translate("Defaults", 'Error'),
                                     translate("Playlist", 'The playlist is not encoded in UTF-8'))
         except Exception as e:
             QMessageBox.information(self._table, translate("Defaults", 'Error'),
-                                    translate("Playlist", 'An error occured while reading <b>%1</b> (%2)').arg(filename).arg(str(e)))
+                                    translate('Playlist',
+                                              "An error occured while reading <b>{}</b> ({})"
+                                              ).format(filename, str(e))
+                                    )
 
     def openDir(self, filename=None, append=False):
         """Opens a folder. If filename != None, then
@@ -891,6 +902,7 @@ class MainWin(QMainWindow):
 
                 model.updateTable(failed_rows)
             return fin()
+
         return func, finished, rows
 
     def writeTags(self, tagiter, rows=None, previews=None):
@@ -940,7 +952,7 @@ class MainWin(QMainWindow):
         setRowData = model.setRowData
 
         [setRowData(row, d, undo=False, temp=True) for row in rows]
-        columns = [_f for _f in map(model.columns.get, d) if _f]
+        columns = set(idx for idx, field in model.columns.items() if field in d)
         if columns:
             start = model.index(min(rows), min(columns))
             end = model.index(max(rows), max(columns))
@@ -955,7 +967,9 @@ class MainWin(QMainWindow):
 
         [setRowData(row, d, undo=False, temp=True) for row, d in
          zip(rows, tags)]
-        columns = set([model.columns.get(tagname) for tag in tags for tagname in tag if tagname in model.columns])
+        columns = set(idx for idx, field in model.columns.items()
+                      for tag in tags  for tagname in tag
+                      if field == tagname)
         if columns:
             start = model.index(min(rows), min(columns))
             end = model.index(max(rows), max(columns))
@@ -1006,9 +1020,9 @@ class MainWin(QMainWindow):
                     setRowData(row, {tag: filename}, True, True)
                     yield None
                 except EnvironmentError as e:
-                    m = translate("Dir Renaming",
-                                  'An error occured while renaming <b>%1</b> to ' \
-                                  '<b>%2</b>. (%3)').arg(audio[PATH]).arg(filename).arg(e.strerror)
+                    m = translate('Dir Renaming',
+                                  "An error occured while renaming <b>{}</b> to <b>{}</b>. ({})"
+                                  ).format(audio[PATH], filename, e.strerror)
                     if row == rows[-1]:
                         yield m, 1
                     else:
@@ -1030,7 +1044,9 @@ class MainWin(QMainWindow):
                 if self._lastdir and olddir in self._lastdir:
                     self._lastdir[self._lastdir.index(olddir)] = newdir
             except (IOError, OSError) as detail:
-                msg = translate("Dir Renaming", "I couldn't rename: <i>%1</i> to <b>%2</b> (%3)").arg(olddir).arg(newdir).arg(detail.strerror)
+                msg = translate('Dir Renaming',
+                                "I couldn't rename: <i>{}</i> to <b>{}</b> ({})"
+                                ).format(olddir, newdir, detail.strerror)
                 if index == len(dirs) - 1:
                     dirlen = 1
                 else:
